{% load url from future %}
{% load emoji_tags %}
{% load comments %}
<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <title>{% block title %}Mini blog{% endblock %}</title>
    <!--[if lt IE 9]>
    <script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script>
    <![endif]-->
    <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/style.css">
    <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/smartphone_style.css">
    <meta name="viewport" content="width=device-width,initial-scale=1.0,minimum-scale=1.0,maximum-scale=1.0,user-scalable=0">
</head>
<body>
    <div id="container">
        <header>
            <figure id="logo">
                <h1><a href="/">Mini blog</a></h1>
                <p>Mini blog powered by Django</p>
                <p>Smartphone mode</p>
            </figure>
            <nav>
                <ul>
                    {% if user.is_authenticated %}
                    <li id="create-new-entry"><a href="{% url 'blogs-entry-create' %}">Create new entry</a></li>
                    <li id="logout"><a href="{% url 'django.contrib.auth.views.logout' %}">Logout</a></li>
                    <li id="admin"><a href="{% url 'admin:index' %}">Admin</a></li>
                    {% else %}
                    <li id="login"><a href="{% url 'django.contrib.auth.views.login' %}">Login</a></li>
                    {% endif %}
                </ul>
            </nav>
        </header>
        <section id="contents">
            <section id="notification">
                <p>You are browsing this site with <strong>{{ device.name }}</strong> and
                    your flavour is <strong><code>{{ flavour }}</code><strong></p>
                <table style="width:80%; margin: 10px auto; text-align: left;">
                    <tr>
                        <td>Kind</td>
                        <td>{{ device.kind }}</td>
                    </tr>
                    <tr>
                        <td>Name</td>
                        <td>{{ device.name }}</td>
                    </tr>
                    <tr>
                        <td>Model</td>
                        <td>{{ device.model }}</td>
                    </tr>
                    <tr>
                        <td>Version</td>
                        <td>{{ device.version }}</td>
                    </tr>
                    <tr>
                        <td>Support cookie</td>
                        <td>{{ device.support_cookie }}</td>
                    </tr>
                    <tr>
                        <td>UID</td>
                        <td>{{ device.uid }}</td>
                    </tr>
                    <tr>
                        <td>Is reliable</td>
                        <td>{{ device.reliable }}</td>
                    </tr>
                </table>
                <p>
                    {% emoji '000' %}{% emoji '001' %} {% emoji '002' %}
                    {% emoji '003' %}{% emoji '004' %} {% emoji '005' %}
                    {% emoji '006' %}{% emoji '007' %} {% emoji '008' %}
                    {% emoji '009' %}{% emoji '010' %} {% emoji '011' %}
                </p>
            </section>
            <section id="main-contents">
            {% block contents %}
            {% endblock %}
            </section>
            <section id="comment-section">
                <h1>For testing POST</h1>
                {% with next=request.path %}
                    {% render_comment_form for contenttypes.contenttype 1 %}
                {% endwith %}
                {% render_comment_list for contenttypes.contenttype 1 %}
            </section>
        </section>
        <footer>
            <p>Copyright &copy; 2011 Alisue, hashnote.net</p>
        </footer>
    </div>
</body>
</html>
