{% extends 'registration/base.html' %}
{% load url from future %}
{% load i18n %}

{% block title %}{% trans 'Logged out' %}{% endblock %}

{% block content_title %}<h1>{% trans 'Logged out' %}</h1>{% endblock %}

{% block contents %}
{{ block.super }}
<p>{% trans 'You are logged out.' %}</p>
{% endblock %}
